==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/VirtualServiceListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface VirtualServiceListFluent<A extends VirtualServiceListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,VirtualService item);
    public A setToItems(int index,VirtualService item);
    public A addToItems(VirtualService... items);
    public A addAllToItems(Collection<VirtualService> items);
    public A removeFromItems(VirtualService... items);
    public A removeAllFromItems(Collection<VirtualService> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<VirtualService> getItems();
    public List<VirtualService> buildItems();
    public VirtualService buildItem(int index);
    public VirtualService buildFirstItem();
    public VirtualService buildLastItem();
    public VirtualService buildMatchingItem(Predicate<VirtualServiceBuilder> predicate);
    public A withItems(List<VirtualService> items);
    public A withItems(VirtualService... items);
    public Boolean hasItems();
    public VirtualServiceListFluent.ItemsNested<A> addNewItem();
    public VirtualServiceListFluent.ItemsNested<A> addNewItemLike(VirtualService item);
    public VirtualServiceListFluent.ItemsNested<A> setNewItemLike(int index,VirtualService item);
    public VirtualServiceListFluent.ItemsNested<A> editItem(int index);
    public VirtualServiceListFluent.ItemsNested<A> editFirstItem();
    public VirtualServiceListFluent.ItemsNested<A> editLastItem();
    public VirtualServiceListFluent.ItemsNested<A> editMatchingItem(Predicate<VirtualServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,VirtualServiceFluent<VirtualServiceListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/VirtualServiceListFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface VirtualServiceListFluent<A extends VirtualServiceListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,VirtualService item);
    public A setToItems(int index,VirtualService item);
    public A addToItems(VirtualService... items);
    public A addAllToItems(Collection<VirtualService> items);
    public A removeFromItems(VirtualService... items);
    public A removeAllFromItems(Collection<VirtualService> items);
    public A removeMatchingFromItems(Predicate<VirtualServiceBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<VirtualService> getItems();
    public List<VirtualService> buildItems();
    public VirtualService buildItem(int index);
    public VirtualService buildFirstItem();
    public VirtualService buildLastItem();
    public VirtualService buildMatchingItem(Predicate<VirtualServiceBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<VirtualServiceBuilder> predicate);
    public A withItems(List<VirtualService> items);
    public A withItems(VirtualService... items);
    public Boolean hasItems();
    public VirtualServiceListFluent.ItemsNested<A> addNewItem();
    public VirtualServiceListFluent.ItemsNested<A> addNewItemLike(VirtualService item);
    public VirtualServiceListFluent.ItemsNested<A> setNewItemLike(int index,VirtualService item);
    public VirtualServiceListFluent.ItemsNested<A> editItem(int index);
    public VirtualServiceListFluent.ItemsNested<A> editFirstItem();
    public VirtualServiceListFluent.ItemsNested<A> editLastItem();
    public VirtualServiceListFluent.ItemsNested<A> editMatchingItem(Predicate<VirtualServiceBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,VirtualServiceFluent<VirtualServiceListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}
